@@ -24,7 +24,7 @@ Sphinx::Search - Sphinx search engine API Perl client
 
 Please note that you *MUST* install a version which is compatible with your version of Sphinx.
 
-Use version 0.25_02 for Sphinx svn-2575
+Use version 0.25_03 for Sphinx svn-2575
 
 Use version 0.24.1 for Sphinx-1.10-beta (svn-2420)
 
@@ -52,7 +52,7 @@ Use version 0.02 for Sphinx 0.9.8-cvs-20070818
 
 =cut
 
-our $VERSION = '0.25_02';
+our $VERSION = '0.25_03';
 
 =head1 SYNOPSIS
 
@@ -1508,7 +1508,7 @@ the same keys as the hash returned by L<Query>, plus:
 
 Errors, if any, for this query.
 
-=item * warnings
+=item * warning
 	
 Any warnings associated with the query.
 
@@ -1552,7 +1552,7 @@ sub RunQueries {
 	push(@results, $result);
 	$result->{matches} = []; # Empty array ref
 	$result->{error} = "";
-	$result->{warnings} = "";
+	$result->{warning} = "";
 
 	# extract status
 	my $status = unpack("N", substr ( $response, $p, 4 ) ); $p += 4;
@@ -2180,6 +2180,8 @@ motivations for branching from the earlier work.
 
 Jon Schutz
 
+L<http://notes.jschutz.net>
+
 =head1 BUGS
 
 Please report any bugs or feature requests to
